@@ -23,6 +23,7 @@ use Sim::OPT::Sim;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
 use Sim::OPT::Modish;
+use Parallel::ForkManager;
 use Data::Dumper;
 #$Data::Dumper::Indent = 0;
 #$Data::Dumper::Useqq  = 1;
@@ -73,6 +74,7 @@ sub retrieve
   $tofile = $main::tofile;
   $report = $main::report;
   $simnetwork = $main::simnetwork;
+  $max_processes = $main::max_processes;
   
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
   
@@ -155,9 +157,10 @@ sub retrieve
   #if ( fileno (MORPHLIST)
   
   my $countinstance = 0;
+  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   foreach my $instance (@instances)
   {
-    
+    my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -837,6 +840,7 @@ $printthis
         }  
       }
     }
+     $pm->finish; # Terminates the child process
     $countinstance++;
   }
   
@@ -938,10 +942,11 @@ sub report # This function retrieves the results of interest from the texts file
   $" = " ";
   my $repfile;
   #my @convey;
+  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   my $countinstance = 0;
   foreach my $instance ( @instances )
   {
-    
+    my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -1202,6 +1207,7 @@ sub report # This function retrieves the results of interest from the texts file
     #push ( @{ $convey[ $countcase ][ $counblock ] }, $lin );
       say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
     }
+    $pm->finish; # Terminates the child process
     $countinstance++;
   }
   
