@@ -1,7 +1,7 @@
 package Sim::OPT::Sim;
 # Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano.
 # This is the module Sim::OPT::Sim of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
-# This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
+# This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
  
 use v5.14;
 # use v5.20;
@@ -33,6 +33,8 @@ use Sim::OPT::Morph;
 use Sim::OPT::Report;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
+use Sim::OPT::Modish;
+use Parallel::ForkManager;
 no strict; 
 no warnings;
 use warnings::unused;
@@ -42,7 +44,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.51'; # our $VERSION = '';
+$VERSION = '0.53'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.'; 
 
 #########################################################################################
@@ -84,6 +86,7 @@ sub sim    # This function launch the simulations in ESP-r
   $tofile = $main::tofile;
   $report = $main::report;
   $simnetwork = $main::simnetwork;
+  $max_processes = $main::max_processes;
   
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
   
@@ -149,8 +152,10 @@ sub sim    # This function launch the simulations in ESP-r
   my @container;
   
   my $countinstance = 0;
+  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   foreach my $instance (@instances)
   {
+    my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -556,6 +561,7 @@ $printthis
       }
       $counttool++;
     }  
+    $pm->finish; # Terminates the child process
     $countinstance++;
   }
   close SIMLIST;
@@ -603,7 +609,7 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
+Copyright (C) 2008-2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 =cut
